@@ -29,8 +29,8 @@ plot.tri<-function(tri.obj,add=F,xlim=range(tri.obj$x),ylim=range(tri.obj$y),...
     {
       inb<-ans$tnabor[i,ans$tnabor[i,]>0]
       for (j in inb)
-      lines(c(tri.obj$x[i],tri.obj$x[j]),c(tri.obj$y[i],tri.obj$y[j]), ...)
+        lines(c(tri.obj$x[i],tri.obj$x[j]),c(tri.obj$y[i],tri.obj$y[j]), ...)
     }
   points(tri.obj$x,tri.obj$y)
-  title("Delaunay triangulation",deparse(substitute(tri.obj)))
+  if(!add) title("Delaunay triangulation",deparse(substitute(tri.obj)))
 }
